FileUploadsService class

Service for interacting with Notion File Uploads API

Constructors

FileUploadsService(NotionHttpClient _httpClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete(String fileUploadId) Future<FileUpload>
Complete a multi-part upload after all parts have been uploaded
create({required FileUploadMode mode, String? filename, String? contentType, int? numberOfParts, String? externalUrl}) Future<FileUpload>
Create a file upload session
list({FileUploadStatus? status, String? startCursor, int? pageSize}) Future<PaginatedList<FileUpload>>
List file uploads for the current integration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieve(String fileUploadId) Future<FileUpload>
Retrieve a single file upload
sendBytes(String fileUploadId, List<int> bytes, {required String filename, String? contentType, int? partNumber}) Future<FileUpload>
Send file contents (multipart/form-data) from a byte buffer
sendFile(String fileUploadId, String filePath, {String? filename, String? contentType, int? partNumber}) Future<FileUpload>
Send file contents (multipart/form-data) from a file path
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited