PageIcon class

Represents a page icon (either emoji or file)

Implementers
Annotations
  • @Freezed.new(toJson: false, fromJson: false)

Constructors

PageIcon.customEmoji({required String id, required String name, required String url})
const
factory
PageIcon.emoji({required String emoji})
const
factory
PageIcon.file({required NotionFile file})
const
factory
PageIcon.fromJson(Map<String, dynamic> json)
factory
PageIcon.notionIcon({required String name, String? color})
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult emoji(EmojiPageIcon value), required TResult file(FilePageIcon value), required TResult customEmoji(CustomEmojiPageIcon value), required TResult notionIcon(NotionNativePageIcon value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? emoji(EmojiPageIcon value)?, TResult? file(FilePageIcon value)?, TResult? customEmoji(CustomEmojiPageIcon value)?, TResult? notionIcon(NotionNativePageIcon value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult emoji(EmojiPageIcon value)?, TResult file(FilePageIcon value)?, TResult customEmoji(CustomEmojiPageIcon value)?, TResult notionIcon(NotionNativePageIcon value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult emoji(String emoji)?, TResult file(NotionFile file)?, TResult customEmoji(String id, String name, String url)?, TResult notionIcon(String name, String? color)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult emoji(String emoji), required TResult file(NotionFile file), required TResult customEmoji(String id, String name, String url), required TResult notionIcon(String name, String? color)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? emoji(String emoji)?, TResult? file(NotionFile file)?, TResult? customEmoji(String id, String name, String url)?, TResult? notionIcon(String name, String? color)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited