ParagraphBlockBuilder class

Builder for paragraph blocks

Constructors

ParagraphBlockBuilder([String? text])

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRichText(Map<String, dynamic> richText) ParagraphBlockBuilder
Adds a rich text element (created with RichTextBuilder)
addText(String text) ParagraphBlockBuilder
Adds plain text to the paragraph
children(List<Map<String, dynamic>> children) ParagraphBlockBuilder
Adds child blocks
color(String color) ParagraphBlockBuilder
Sets the block color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the builder to a JSON-compatible Map
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited