Parent class

Parent object representing the location of a page, database, or block

Implementers
Annotations
  • @Freezed.new(toJson: false, fromJson: false)

Constructors

Parent.block({required String blockId})
const
factory
Parent.database({required String databaseId})
const
factory
Parent.dataSource({required String dataSourceId, String? databaseId})
const
factory
Parent.fromJson(Map<String, dynamic> json)
factory
Parent.page({required String pageId})
const
factory
Parent.workspace()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult database(DatabaseParent value), required TResult dataSource(DataSourceParent value), required TResult page(PageParent value), required TResult workspace(WorkspaceParent value), required TResult block(BlockParent value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? database(DatabaseParent value)?, TResult? dataSource(DataSourceParent value)?, TResult? page(PageParent value)?, TResult? workspace(WorkspaceParent value)?, TResult? block(BlockParent value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult database(DatabaseParent value)?, TResult dataSource(DataSourceParent value)?, TResult page(PageParent value)?, TResult workspace(WorkspaceParent value)?, TResult block(BlockParent value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult database(String databaseId)?, TResult dataSource(String dataSourceId, String? databaseId)?, TResult page(String pageId)?, TResult workspace()?, TResult block(String blockId)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult database(String databaseId), required TResult dataSource(String dataSourceId, String? databaseId), required TResult page(String pageId), required TResult workspace(), required TResult block(String blockId)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? database(String databaseId)?, TResult? dataSource(String dataSourceId, String? databaseId)?, TResult? page(String pageId)?, TResult? workspace()?, TResult? block(String blockId)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited