QuoteBlockBuilder class
Builder for quote blocks
Constructors
- QuoteBlockBuilder(String _text)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
children(
List< Map< children) → QuoteBlockBuilderString, dynamic> > - Adds child blocks
-
color(
String color) → QuoteBlockBuilder - Sets the quote color
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts the builder to a JSON-compatible Map
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited