RichTextBuilder class

Main entry point for building rich text objects

Provides static factory methods for creating different rich text types: text, mentions, and equations.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

equation(String expression) EquationRichTextBuilder
Creates an equation
mentionDatabase(String databaseId) MentionRichTextBuilder
Creates a database mention
mentionDate({required DateTime start, DateTime? end}) MentionRichTextBuilder
Creates a date mention
mentionLinkPreview(String url) MentionRichTextBuilder
Creates a link preview mention
mentionPage(String pageId) MentionRichTextBuilder
Creates a page mention
mentionUser(String userId) MentionRichTextBuilder
Creates a user mention
plainArray(String text) List<Map<String, dynamic>>
Helper method to create a simple plain text array
text(String content) TextRichTextBuilder
Creates a text rich text builder