RollupPropertySchema class abstract

Inheritance

Constructors

RollupPropertySchema({required String id, required String name, required String rollupPropertyName, required String relationPropertyName, required String rollupPropertyId, required String relationPropertyId, required String function})
const
factory

Properties

copyWith → _$$RollupPropertySchemaImplCopyWith<_$RollupPropertySchemaImpl>
Create a copy of PropertySchema with the given fields replaced by the non-null parameter values.
no setter
function String
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
no setter
name String
no setter
relationPropertyId String
no setter
relationPropertyName String
no setter
rollupPropertyId String
no setter
rollupPropertyName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult checkbox(CheckboxPropertySchema value), required TResult richText(RichTextPropertySchema value), required TResult title(TitlePropertySchema value), required TResult number(NumberPropertySchema value), required TResult select(SelectPropertySchema value), required TResult multiSelect(MultiSelectPropertySchema value), required TResult status(StatusPropertySchema value), required TResult date(DatePropertySchema value), required TResult people(PeoplePropertySchema value), required TResult files(FilesPropertySchema value), required TResult email(EmailPropertySchema value), required TResult phoneNumber(PhoneNumberPropertySchema value), required TResult url(UrlPropertySchema value), required TResult createdTime(CreatedTimePropertySchema value), required TResult createdBy(CreatedByPropertySchema value), required TResult lastEditedTime(LastEditedTimePropertySchema value), required TResult lastEditedBy(LastEditedByPropertySchema value), required TResult formula(FormulaPropertySchema value), required TResult relation(RelationPropertySchema value), required TResult rollup(RollupPropertySchema value), required TResult uniqueId(UniqueIdPropertySchema value), required TResult verification(VerificationPropertySchema value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? checkbox(CheckboxPropertySchema value)?, TResult? richText(RichTextPropertySchema value)?, TResult? title(TitlePropertySchema value)?, TResult? number(NumberPropertySchema value)?, TResult? select(SelectPropertySchema value)?, TResult? multiSelect(MultiSelectPropertySchema value)?, TResult? status(StatusPropertySchema value)?, TResult? date(DatePropertySchema value)?, TResult? people(PeoplePropertySchema value)?, TResult? files(FilesPropertySchema value)?, TResult? email(EmailPropertySchema value)?, TResult? phoneNumber(PhoneNumberPropertySchema value)?, TResult? url(UrlPropertySchema value)?, TResult? createdTime(CreatedTimePropertySchema value)?, TResult? createdBy(CreatedByPropertySchema value)?, TResult? lastEditedTime(LastEditedTimePropertySchema value)?, TResult? lastEditedBy(LastEditedByPropertySchema value)?, TResult? formula(FormulaPropertySchema value)?, TResult? relation(RelationPropertySchema value)?, TResult? rollup(RollupPropertySchema value)?, TResult? uniqueId(UniqueIdPropertySchema value)?, TResult? verification(VerificationPropertySchema value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult checkbox(CheckboxPropertySchema value)?, TResult richText(RichTextPropertySchema value)?, TResult title(TitlePropertySchema value)?, TResult number(NumberPropertySchema value)?, TResult select(SelectPropertySchema value)?, TResult multiSelect(MultiSelectPropertySchema value)?, TResult status(StatusPropertySchema value)?, TResult date(DatePropertySchema value)?, TResult people(PeoplePropertySchema value)?, TResult files(FilesPropertySchema value)?, TResult email(EmailPropertySchema value)?, TResult phoneNumber(PhoneNumberPropertySchema value)?, TResult url(UrlPropertySchema value)?, TResult createdTime(CreatedTimePropertySchema value)?, TResult createdBy(CreatedByPropertySchema value)?, TResult lastEditedTime(LastEditedTimePropertySchema value)?, TResult lastEditedBy(LastEditedByPropertySchema value)?, TResult formula(FormulaPropertySchema value)?, TResult relation(RelationPropertySchema value)?, TResult rollup(RollupPropertySchema value)?, TResult uniqueId(UniqueIdPropertySchema value)?, TResult verification(VerificationPropertySchema value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult checkbox(String id, String name)?, TResult richText(String id, String name)?, TResult title(String id, String name)?, TResult number(String id, String name, String format)?, TResult select(String id, String name, List<SelectOption> options)?, TResult multiSelect(String id, String name, List<SelectOption> options)?, TResult status(String id, String name, List<StatusOption> options, Map<String, List<String>> groups)?, TResult date(String id, String name)?, TResult people(String id, String name)?, TResult files(String id, String name)?, TResult email(String id, String name)?, TResult phoneNumber(String id, String name)?, TResult url(String id, String name)?, TResult createdTime(String id, String name)?, TResult createdBy(String id, String name)?, TResult lastEditedTime(String id, String name)?, TResult lastEditedBy(String id, String name)?, TResult formula(String id, String name, String expression)?, TResult relation(String id, String name, String databaseId, String? syncedPropertyName, String? syncedPropertyId)?, TResult rollup(String id, String name, String rollupPropertyName, String relationPropertyName, String rollupPropertyId, String relationPropertyId, String function)?, TResult uniqueId(String id, String name, String? prefix)?, TResult verification(String id, String name)?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult checkbox(String id, String name), required TResult richText(String id, String name), required TResult title(String id, String name), required TResult number(String id, String name, String format), required TResult select(String id, String name, List<SelectOption> options), required TResult multiSelect(String id, String name, List<SelectOption> options), required TResult status(String id, String name, List<StatusOption> options, Map<String, List<String>> groups), required TResult date(String id, String name), required TResult people(String id, String name), required TResult files(String id, String name), required TResult email(String id, String name), required TResult phoneNumber(String id, String name), required TResult url(String id, String name), required TResult createdTime(String id, String name), required TResult createdBy(String id, String name), required TResult lastEditedTime(String id, String name), required TResult lastEditedBy(String id, String name), required TResult formula(String id, String name, String expression), required TResult relation(String id, String name, String databaseId, String? syncedPropertyName, String? syncedPropertyId), required TResult rollup(String id, String name, String rollupPropertyName, String relationPropertyName, String rollupPropertyId, String relationPropertyId, String function), required TResult uniqueId(String id, String name, String? prefix), required TResult verification(String id, String name)}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? checkbox(String id, String name)?, TResult? richText(String id, String name)?, TResult? title(String id, String name)?, TResult? number(String id, String name, String format)?, TResult? select(String id, String name, List<SelectOption> options)?, TResult? multiSelect(String id, String name, List<SelectOption> options)?, TResult? status(String id, String name, List<StatusOption> options, Map<String, List<String>> groups)?, TResult? date(String id, String name)?, TResult? people(String id, String name)?, TResult? files(String id, String name)?, TResult? email(String id, String name)?, TResult? phoneNumber(String id, String name)?, TResult? url(String id, String name)?, TResult? createdTime(String id, String name)?, TResult? createdBy(String id, String name)?, TResult? lastEditedTime(String id, String name)?, TResult? lastEditedBy(String id, String name)?, TResult? formula(String id, String name, String expression)?, TResult? relation(String id, String name, String databaseId, String? syncedPropertyName, String? syncedPropertyId)?, TResult? rollup(String id, String name, String rollupPropertyName, String relationPropertyName, String rollupPropertyId, String relationPropertyId, String function)?, TResult? uniqueId(String id, String name, String? prefix)?, TResult? verification(String id, String name)?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited