TemplatesService class

Service for interacting with Notion Templates API

Provides methods to retrieve templates from data sources. Templates are predefined page structures that can be used to create new pages.

Constructors

TemplatesService(NotionHttpClient _httpClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listTemplates(String dataSourceId, {String? startCursor, int? pageSize}) Future<PaginatedList<Template>>
Retrieves a list of templates from a data source
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieveTemplate(String dataSourceId, String templateId) Future<Template>
Retrieves a specific template by ID from a data source
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited