UniqueId class

Unique ID value

Annotations
  • @freezed

Constructors

UniqueId({required int number, String? prefix})
const
factory
UniqueId.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UniqueIdCopyWith<UniqueId>
Create a copy of UniqueId with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
number int
no setterinherited
prefix String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UniqueId to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited