ViewsService class

Service for Notion Views API.

Constructors

ViewsService(NotionHttpClient _httpClient)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create({required String dataSourceId, required String name, required String type, String? databaseId, String? viewId, Map<String, dynamic>? createDatabase, Map<String, dynamic>? filter, List<Map<String, dynamic>>? sorts, Map<String, dynamic>? configuration, Map<String, dynamic>? position}) Future<View>
Creates a view.
createQuery(String viewId) Future<ViewQuery>
Creates a cached query for a view and returns the first page of results.
delete(String viewId) Future<View>
Deletes a view by ID.
deleteQuery(String viewId, String queryId) Future<Map<String, dynamic>>
Deletes a cached view query.
list({String? databaseId, String? dataSourceId, String? startCursor, int? pageSize}) Future<PaginatedList<View>>
Lists views by database or data source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
retrieve(String viewId) Future<View>
Retrieves a view by ID.
retrieveQueryResults(String viewId, String queryId, {String? startCursor, int? pageSize}) Future<ViewQuery>
Retrieves a page of results from a cached view query.
toString() String
A string representation of this object.
inherited
update(String viewId, {String? name, Map<String, dynamic>? filter, List<Map<String, dynamic>>? sorts, Map<String, dynamic>? configuration}) Future<View>
Updates a view by ID.

Operators

operator ==(Object other) bool
The equality operator.
inherited