Properties
-
copyWith
→ _$$DatabaseParentImplCopyWith<_$DatabaseParentImpl>
-
Create a copy of Parent
with the given fields replaced by the non-null parameter values.
no setter
-
databaseId
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
map<TResult extends Object?>({required TResult database(DatabaseParent value), required TResult dataSource(DataSourceParent value), required TResult page(PageParent value), required TResult workspace(WorkspaceParent value), required TResult block(BlockParent value)})
→ TResult
-
inherited
-
mapOrNull<TResult extends Object?>({TResult? database(DatabaseParent value)?, TResult? dataSource(DataSourceParent value)?, TResult? page(PageParent value)?, TResult? workspace(WorkspaceParent value)?, TResult? block(BlockParent value)?})
→ TResult?
-
inherited
-
maybeMap<TResult extends Object?>({TResult database(DatabaseParent value)?, TResult dataSource(DataSourceParent value)?, TResult page(PageParent value)?, TResult workspace(WorkspaceParent value)?, TResult block(BlockParent value)?, required TResult orElse()})
→ TResult
-
inherited
-
maybeWhen<TResult extends Object?>({TResult database(String databaseId)?, TResult dataSource(String dataSourceId, String? databaseId)?, TResult page(String pageId)?, TResult workspace()?, TResult block(String blockId)?, required TResult orElse()})
→ TResult
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
when<TResult extends Object?>({required TResult database(String databaseId), required TResult dataSource(String dataSourceId, String? databaseId), required TResult page(String pageId), required TResult workspace(), required TResult block(String blockId)})
→ TResult
-
inherited
-
whenOrNull<TResult extends Object?>({TResult? database(String databaseId)?, TResult? dataSource(String dataSourceId, String? databaseId)?, TResult? page(String pageId)?, TResult? workspace()?, TResult? block(String blockId)?})
→ TResult?
-
inherited