FileUpload class
Represents a File Upload object in Notion
Constructors
- FileUpload({required String id, required String object, required DateTime createdTime, required DateTime lastEditedTime, required bool archived, required FileUploadStatus status, required String filename, required String contentType, required int contentLength, DateTime? expiryTime, String? uploadUrl})
-
const
-
FileUpload.fromJson(Map<
String, dynamic> json) -
factory
Properties
- archived → bool
-
final
- contentLength → int
-
final
- contentType → String
-
final
- createdTime → DateTime
-
final
- expiryTime → DateTime?
-
final
- filename → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- lastEditedTime → DateTime
-
final
- object → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → FileUploadStatus
-
final
- uploadUrl → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited