PropertyItemList class
Represents a paginated list of property items
- Annotations
-
- @freezed
Constructors
-
PropertyItemList({required List<
PropertyItem> results, required PropertyItem propertyItem, @Default.new('list') String object, @Default.new('property_item') String type, String? nextUrl, @Default.new(false) bool hasMore, String? nextCursor}) -
constfactory
-
PropertyItemList.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $PropertyItemListCopyWith<
PropertyItemList> -
Create a copy of PropertyItemList
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasMore → bool
-
Whether there are more results
no setterinherited
- nextCursor → String?
-
Cursor for pagination
no setterinherited
- nextUrl → String?
-
URL for next page of results
no setterinherited
- object → String
-
Always "list"
no setterinherited
- propertyItem → PropertyItem
-
Property item object that describes the property
no setterinherited
-
results
→ List<
PropertyItem> -
List of property item objects
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Always "property_item"
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited